import os
import uuid
import click
from click_help_colors import HelpColorsGroup
import click_spinner


@click.group(
    cls=HelpColorsGroup, help_headers_color="yellow", help_options_color="green"
)
def cli_init():
    pass


@cli_init.command()
@click.option(
    "--guidename",
    prompt="Name your guide",
    help="What would you like to call this guide?",
)
@click.option(
    "--authorname", prompt="Your name", help="Who is the author of this guide?"
)
def create(guidename, authorname):
    guidename = guidename.replace(' ', '')
    
    click.echo(f"Hi, {authorname}")
    click.echo(f"Your guide will be called '{guidename}'")
    click.echo()

    directory = prompt_output_directory()

    click.echo()
    click.echo(f"Guide name: {guidename}")
    click.echo(f"Author name: {authorname}")
    click.echo(f"Directory: {directory}")
    click.echo()

    final_confirmation = click.confirm(f"Are these details correct?", default=True)
    if not final_confirmation:
        click.echo(f"Guide creation is cancelled. Please start again.")
        return

    click.echo(f"Creating your guide now...")
    with click_spinner.spinner():
        click.echo()

        # Create Guide Step Definition
        sample_guide_step_template = get_sample_guide_step()
        if not sample_guide_step_template:
            click.echo(
                f"Guide template could not be located. Please contact Switch Automation for assistance.",
                err=True,
            )
            return
        
        if not os.path.isdir(directory):
            os.mkdir(directory)

        sample_guide_step_template = sample_guide_step_template.replace(
            "{GuideName_Template}", guidename
        )

        guide_step_class_name = f"{guidename}GuideStepDefinition"

        sample_guide_step_template = sample_guide_step_template.replace(
            "GuideSampleStepName_Template", guide_step_class_name
        )
        guide_step_definition_id = f"{uuid.uuid4()}"
        sample_guide_step_template = sample_guide_step_template.replace(
            "{GuideStepDefinitionId_Template}", guide_step_definition_id
        )
        sample_guide_step_template = sample_guide_step_template.replace(
            "{Author_Template}", authorname
        )

        output_guide_path = os.path.join(directory, f"{guide_step_class_name}.py")
        with open(output_guide_path, "w") as output_file:
            output_file.write(sample_guide_step_template)

        # Create Guide Definition
        sample_guide_template = get_sample_guide()
        if not sample_guide_template:
            click.echo(
                f"Guide template could not be located. Please contact Switch Automation for assistance.",
                err=True,
            )
            return

        sample_guide_template = sample_guide_template.replace(
            "{GuideName_Template}", guidename
        )

        guide_class_name = f"{guidename}GuideDefinition"

        sample_guide_template = sample_guide_template.replace(
            "GuideSampleClassName_Template", guide_class_name
        )
        sample_guide_template = sample_guide_template.replace(
            "{GuideDefinitionId_Template}", f"{uuid.uuid4()}"
        )
        sample_guide_template = sample_guide_template.replace(
            "{Author_Template}", authorname
        )
        sample_guide_template = sample_guide_template.replace(
            "{GuideStepDefinitionId_Template}", guide_step_definition_id
        )

        output_guide_path = os.path.join(directory, f"{guide_class_name}.py")
        with open(output_guide_path, "w") as output_file:
            output_file.write(sample_guide_template)

        click.echo(f"Guide definition files where created successfully")


def prompt_output_directory():
    dir_confirmation = False
    default_dir = f"{os.getcwd()}\generated_guides"

    while not dir_confirmation:
        directory = click.prompt(
            f"Which directory would you like your guide definitions created in?",
            default=default_dir,
        )

        if not os.path.isdir(directory):
            click.echo(
                "Directory will be created on completion of this as it does not exist yet."
            )

        dir_confirmation = click.confirm(
            f"Are you sure you would like to your guides at `{directory}`?",
            default=True,
        )
    return directory


def valid_step_count(number):
    try:
        number = int(number)
        if number < 1 or number > 9:
            return False
        return True
    except:
        return False


def get_sample_guide():
    dir_path = os.path.dirname(os.path.realpath(__file__))
    templates_path = os.path.join(dir_path, "templates")
    if not os.path.isdir(templates_path):
        return None

    guide_sample_path = os.path.join(templates_path, "guide_sample_definition.py")

    with open(guide_sample_path, encoding="utf-8") as f:
        return f.read()


def get_sample_guide_step():
    dir_path = os.path.dirname(os.path.realpath(__file__))
    templates_path = os.path.join(dir_path, "templates")
    if not os.path.isdir(templates_path):
        return None

    guide_sample_path = os.path.join(templates_path, "guide_sample_step_definition.py")

    with open(guide_sample_path, encoding="utf-8") as f:
        return f.read()


@cli_init.command()
def list():
    click.echo(f"Not implemented yet.")


if __name__ == "__main__":
    cli_init()



import click
import logging
import switch_guides_scaffold.taskinsights.enums as ti_enums
import switch_guides_scaffold.taskinsights.validation as ti_validation
import switch_guides_scaffold.taskinsights.transformations as ti_transformations
import typing
from io import StringIO
import jinja2
import os
import uuid
import pandas as pd
import switch_api as sw
import collections

# Registering the main group
@click.group()
def taskinsights():
    logging.info(f"Task Insights.")
    return None


@taskinsights.command()
@click.option(
    "--name",
    type=click.types.STRING,
    prompt="Provide a name of the task.",
    help="<Insert docstring for task type selection here.>",
)
@click.option(
    "--task-type",
    type=click.Choice(ti_enums.TASK_TYPES, case_sensitive=False,),
    prompt="Select the type of task to be created. Note that depending on the task selected, the deployment options may vary.",
    help="<Insert docstring for task type selection here.>",
)
@click.option(
    "--description",
    type=click.types.STRING,
    callback=ti_validation.validate_description,
    prompt="Provide a brief description of the task.",
    help="Fills in the description abstractmethod of the task.",
)
@click.option(
    "--readings-type",
    type=click.Choice(ti_enums.MAPPING_ENTITIES, case_sensitive=False,),
    prompt="Select the class of readings that this data ingestion is meant for.",
    help="<Insert docstring for task type selection here.>",
)
@click.option(
    "--author",
    type=click.types.STRING,
    prompt="Provide a brief description of the task.",
    help="Fills in the description abstractmethod of the task.",
)  # Potentially use the local token to fill in this field in the future.
def create_task(
    name: str, task_type: str, description: str, readings_type: str, author: str
):

    # Loading the template into the environment
    template_location: str = str(
        os.path.dirname(os.path.abspath(__file__))
    ) + r"\templates"
    loader = jinja2.loaders.FileSystemLoader(template_location)
    env = jinja2.environment.Environment(loader=loader)
    template = env.get_template("python_drivers.py.jinja2")

    # Preparing the variables for rendering
    generated_uuid: uuid.UUID = uuid.uuid4()

    output = template.render(
        name=name,
        task_type=task_type,
        uuid=generated_uuid,
        readings_type=readings_type,
        description=description,
        author=author,
    )
    print(output)


@taskinsights.command()
@click.option(
    "--name",
    type=click.types.STRING,
    prompt="Provide a name of the task.",
    help="<Insert docstring for task type selection here.>",
)
@click.option(
    "--filepath",
    type=click.types.STRING,
    callback=ti_validation.validate_filepath,
    prompt="Provide the filepath to the sample file that will be used to build this integration.",
    help="Filepath provided will be used to model the integration steps for this integration.",
)
def integrate_csv(name: str, filepath: str) -> None:

    # CONSTANTS
    CHOICES: typing.Dict[str, str] = {
        "1": "Modify existing column.",
        "2": "Add additional column.",
        "3": "Remove an existing column.",
        "4": "Exit the manipulation step.",
        "U": "Undo the previous step.",
    }

    # Setting Pandas display options
    pd.options.display.max_rows = 6
    pd.options.display.max_columns = None  # type: ignore - Displays all columns.
    pd.options.display.max_colwidth = None  # type: ignore - No limit on the column width.
    pd.options.display.expand_frame_repr = (
        False  # Prevents the printed dataframe from wrapping around
    )
    
    # Intializing the actions queue
    # The purpose of the deque is to allow a maximum amount of backtracking
    df_cache: collections.deque[pd.DataFrame] = collections.deque(maxlen=5) # Arbitarily set to 5 for now.
    code_gen: collections.deque[str] = collections.deque()

    # Initializing the api_inputs
    api_project_id: str = "758c3062-dc2f-4550-ae32-00e5b0f46dc8"  # Pointing towards Data Science - EA - Test - Brandon
    click.echo(f"Checking Switch credentials...")
    api_inputs = sw.initialize(
        api_project_id=api_project_id  # type: ignore
    )
    click.echo(f"Switch credentials validated!")

    # Opening the file
    df = pd.read_csv(filepath_or_buffer=filepath)
    print(f"Working Dataframe:")
    click.echo(df)

    # Manipulating the dataframe
    # actions: typing.List[str] = [] 
    while True:
        print(f"Select the following options for transforming your dataframe: ")
        for k, v in CHOICES.items():
            print(f"{k} - {v}")

        selected_choice: str = click.prompt(
            "Enter your selected choice: ",
            type=click.Choice(list(CHOICES.keys()), case_sensitive=False),
        )
        
        if selected_choice == "1": # Selected the option to modify the column
            df = ti_transformations.modify_column(df)
        elif selected_choice == "2":
            df = ti_transformations.add_column(df, code_gen, df_cache)
        elif selected_choice == "U":
            if click.prompt(text=f"Are you sure you want to undo the previous operation?", type=click.Choice(["Y", "N"], case_sensitive=False)) == "Y":
                click.echo(f"Attempting to undo previous step.")
                if len(df_cache) == 0:
                    click.echo(f"Cannot undo anymore.")
                else:
                    df = df_cache.pop() # Restores to the previous version
                    code_gen.pop() # Removes the last element of the code gen
                    click.echo(f"Undo operation successful.")
                    click.echo(df)
        else:
            print(f"No further manipulations can be done to the table.")
            break
        
    # Loading the template into the environment
    template_location: str = str(
        os.path.dirname(os.path.abspath(__file__))
    ) + r"\templates"
    loader = jinja2.loaders.FileSystemLoader(template_location)
    env = jinja2.environment.Environment(loader=loader)
    template = env.get_template(r"integrate_csv.py.jinja2")

    # Preparing the variables for rendering
    generated_uuid: uuid.UUID = uuid.uuid4()

    output = template.render(
        name=name,
        task_type="IntegrationTask",
        uuid=generated_uuid,
        readings_type="Readings",
        description="foo",
        author="bar",
        code_blocks = code_gen
    )
    print(output)


# @taskinsights.command()
# @click.option(
#     "--name",
#     prompt="Enter your name",
#     help="Name for this."
# )
# @click.option(
#     "--number",
#     prompt="Enter your number",
#     help="Number for this."
# )
# def test(name, number):
#     print(name)
#     print(number)



import uuid
from switch_guides.models.guide import SwitchGuideDefinition, SwitchGuideDefinitionOptions
from switch_guides.models.step import SwitchGuideStepDependency
from switch_guides.tasks.GuideDefinitionTask import GuideDefinitionTask
import switch_api as sw


class GuideSampleClassName_Template(GuideDefinitionTask):
    @property
    def id(self) -> uuid.UUID:
        return uuid.UUID('{GuideDefinitionId_Template}')

    @property
    def author(self):
        return '{Author_Template}'

    @property
    def version(self):
        return '0.1.0'

    @property
    def description(self) -> str:
        return """Sample Guide Definition. This description is not visible to the user. 
            Please update it with one that would help future authors understand the intention of this Guide Step."""

    @property
    def mapping_entities(self):
        return ['Readings']

    @property
    def schema(self):
        pass

    def definition(self) -> SwitchGuideDefinition:
        return SwitchGuideDefinition(
            name='{GuideName_Template}',
            description='', # Description visible to the user
            instructions='', # Instructions visible to the user
            steps=[
                SwitchGuideStepDependency(
                    order=1,
                    stepId="{GuideStepDefinitionId_Template}"
                )
            ],
            options=SwitchGuideDefinitionOptions(
                enable_live_notification=False
            )
        )


task = GuideSampleClassName_Template()

if __name__ == "__main__":
    api_inputs = sw.initialize(api_project_id='96fa3fc9-1bec-4c38-b8d3-bb985e8ad238', environment='Development')

    """ ================== REGISTER TASK ==================
    """

    # response_status, response_data = task.register(api_inputs=api_inputs)

    # print(response_status)
    # print(response_data)



import os
import uuid
import click
from click_help_colors import HelpColorsGroup
import logging

# Click groups
@click.group()
def cli():
    """
    Main group responsible for the CLI interace. All commands will be registered to it.
    """
    logging.info(f"Switch CLI started.")
    return None

@click.group()
def guides():
    logging.info(f"Guides.")
    return None

cli.add_command(guides)

if __name__ == "__main__":
    cli()



import pandas as pd
import switch_api as sw
import click
import typing
import collections
import re
import datetime

# def lambda_builder(input: str) -> typing.Callable[..., typing.Any]:

#     """
#     The purpose of this function is to take a lambda function written as a string and parse it into a proper lambda function
#     """


def modify_column(df) -> pd.DataFrame:

    # Getting the list of columns currently present within the dataframe
    existing_columns: typing.Set[str] = set(df.columns)

    # selected_column = ""
    # while selected_column not in existing_columns:
    #     if selected_column != "":
    #         click.echo(f"Selected column {selected_column} does not exist within the list of column headers.")
    #     selected_column: str = click.prompt("Please enter a column name that needs to be modified.", type=click.types.STRING)

    click.echo(
        f"Enter a lambda function using the form lambda syntax. \n For instance 'lambda [col A], [col B]: [col A] + [col B]'. "
    )
    return df


def add_column(df: pd.DataFrame, code_gen: collections.deque[str], df_cache: collections.deque[pd.DataFrame]):

    COLUMN_VALUE_OPTION: typing.Dict[str, str] = {
        "1": "Copy from existing column.",
        "2": "Insert a common value across all records.",
        "3": "Generate values from existing columns.",
    }

    # Getting the user intput for the column name
    column_name: str = click.prompt(
        text=f"Provide the name of the new column.", type=click.types.STRING
    )
    
    if column_name in set(df.columns):
        click.echo(f"Column name already exists, and thus the existing column will be overwritten. Continue?")
        if click.prompt("Y/N") =="N":
            return df
    
    # Making a copy of the original dataframe
    df_original: pd.DataFrame = pd.DataFrame(
        data=df,
        copy=True
    )

    # Getting the user input for the value that needs to be generated
    print(f"Select the following options for generating the new column: ")
    for k, v in COLUMN_VALUE_OPTION.items():
        print(f"{k} - {v}")

    selected_choice: str = click.prompt(
        "Enter your selected choice: ",
        type=click.Choice(list(COLUMN_VALUE_OPTION.keys()), case_sensitive=False),
    )

    if selected_choice == "1":
        existing_column_name: str = click.prompt(
            f"Select a existing column",
            type=click.Choice(list(df.columns), case_sensitive=False),
        )
        try:
            df[column_name] = df[existing_column_name]
            click.echo(f"Created the column {column_name}!")
            click.echo(df)
        except Exception as e:
            click.echo(f"Unable to perform this operation. See error message raised: {e}")
            return df
        
        # Updating the code gen and the cache
        df_cache.append(df_original)
        code_gen.append(f'df["{column_name}"] = df["{existing_column_name}"]')
    
    if selected_choice == "2":
        
        input_value_raw: str = click.prompt(
            text=f"Provide the value used to populate this column: ",
            type=click.types.STRING
        )
        
        is_numeric: bool = False
        if str.isnumeric(input_value_raw):
            click.echo(f"The input appears to be a numeric value. Evaluate it as a numeric value?")
            if click.prompt(text="Y/N") == "Y":
                is_numeric = True
        
        try:
            if is_numeric:
                df[column_name] = float(input_value_raw)
                code_gen.append(f'df["{column_name}"] = float({input_value_raw})')
            else:
                df[column_name] = str(input_value_raw)
                code_gen.append(f'df["{column_name}"] = str({input_value_raw})')
            click.echo(f"Created the column {column_name} and set the value == {input_value_raw}")
            click.echo(df)
        except Exception as e:
            click.echo(f"Unable to perform this operation. See error message raised: {e}")
            return df
        
        df_cache.append(df_original)
    
    if selected_choice == "3":
        # Concept: Allows python expressions to be written, but the variable names are substituted with column names instead.
        # E.g. ["Column A"].contains("foo") -> outputs a boolean column
        
        COLUMN_REGEX_PATTERN: str = r'(\["[A-z0-9 ]+"\])'
        
        input_function_raw: str = click.prompt(
            text=f"Provide the function that will be applied elementwise: ",
            type=click.types.STRING
        )
        
        # Validating that the input column names are valid (Present within the actual dataframe)
        c: str
        for c in re.findall(COLUMN_REGEX_PATTERN, input_function_raw):
            if c[2:-2] not in df.columns:
                click.echo(f"Column \"{c[2:-2]}\" appears to not be present.")
                return df
        
        # Converting into a lambda function
        lambda_function_str: str = re.sub(
            pattern=COLUMN_REGEX_PATTERN,
            repl=r"row\1",
            string=input_function_raw
        )
        
        # Executing the actual function
        try:
            exec(f'df["{column_name}"] = df.apply(lambda row: {lambda_function_str}, axis = 1)')
            click.echo(df)
            code_gen.append(f'df["{column_name}"] = df.apply(lambda row: {lambda_function_str}, axis = 1)')
        except Exception as e:
            click.echo(f"Unable to perform this operation. See error message raised: {e}")
            return df
        
        # Storing the original into the cache
        df_cache.append(df_original)
        
        return df
        
    return df
        



# -------------------------------------------------------------------------
# Copyright (c) Switch Automation Pty Ltd. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------
"""
Switch Guides Scaffolder into the Switch Automation
=========================================

Complete package for helping with the creation of Platform Guides in Switch Automation Platform.
"""
__all__ = [
]

__version__ = "0.1.7"



import click
import logging
import switch_guides_scaffold.taskinsights.enums as switch_enums
import typing
import os


def validate_description(ctx: click.Context, param: click.Parameter, value: typing.Any):
    while len(value) > 100:
        click.echo(
            "Description is too verbose. Please re-enter a concise description: "
        )
        value = click.prompt("", type=click.types.STRING,)
    return value


def validate_filepath(ctx: click.Context, param: click.Parameter, value: str) -> str:

    # Defining an error_flag
    error_flag: bool = False
    value = str(value)

    # Checking if the filepath is valid
    error_flag = len(value) == 0
    while error_flag:
        click.echo("No filepath is provided. Please enter a proper filepath.")
        value = click.prompt("", type=click.types.STRING,)
        error_flag = len(value) == 0

    # Checking if the filepath exists
    error_flag = os.path.exists(value)
    while not error_flag:
        click.echo("File path does not exist. Please enter a valid filepath.")
        value = click.prompt("", type=click.types.STRING,)
        error_flag = os.path.exists(value)

    # Checking if the filepath exists
    error_flag = os.path.isfile(value)
    while not error_flag:
        click.echo("No file at the provided filepath. Please enter a valid filepath.")
        value = click.prompt("", type=click.types.STRING,)
        error_flag = os.path.isfile(value)

    # Checking if the file is a csv type.
    # NOTE: This is a relatively trivial check that can be easily overcome - Needs improvement as development progresses.
    error_flag = value[-4:] == ".csv"
    while not error_flag:
        click.echo("The provided file does not appear to be of a csv type.")
        value = click.prompt("", type=click.types.STRING,)
        error_flag = value[-4:] == ".csv"

    return str(value)



import typing


TASK_TYPES: typing.List[str] = [
    "IntegrationTask",
    "QueueTask",
    "AnalyticsTask",
    "t" # Used for testing only.
]

MAPPING_ENTITIES: typing.List[str] = ['Installations', 'Devices/Sensors', 'Readings', 'Work Orders']


import click
import logging
import switch_api as sw

from switch_guides_scaffold.guides import guides_commands
from switch_guides_scaffold.taskinsights import task_insights

# Click groups
@click.group()
def cli():
    """
    Main group responsible for the CLI interace. All commands will be registered to it.
    """
    logging.info(f"Switch CLI started.")
    return None

cli.add_command(guides_commands.guides)
cli.add_command(task_insights.taskinsights)

if __name__ == "__main__":
    cli()
    
sw.initialize


# -------------------------------------------------------------------------
# Copyright (c) Switch Automation Pty Ltd. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

# Import required functions
from glob import glob
from setuptools import setup, find_packages

# Call setup function
setup(
    author="Switch Automation Pty Ltd.",
    description="A package for helping with the creation of Platform Guides in Switch Automation Platform.",
    long_description=open('README.md', 'r').read() + '\n\n' + open('HISTORY.md', 'r').read(),
    long_description_content_type='text/markdown',
    license='MIT License',
    name="switch_guides_scaffold",
    version="0.1.7",
    packages=find_packages(
        include=["switch_guides_scaffold", "switch_guides_scaffold.*"],
        exclude=["switch_guides_scaffold.tests", "switch_guides_scaffold.tests.*"]
    ),
    install_requires=['switch-guides', 'click', 'click-help-colors', 'click_spinner', 'pydantic==1.9.0', 'jinja2'],
    python_requires=">=3.8.*",
    entry_points={
        'console_scripts': [
            'swag=switch_guides_scaffold.cli:cli',
            'switchguides=switch_guides_scaffold.cli:cli'
        ]
    },
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        "License :: OSI Approved :: MIT License",
        'Intended Audience :: Other Audience',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Natural Language :: English',
    ],
    package_data={
        '': ['*.jinja2']
    }
)



import uuid
from switch_guides.models.api import SwitchGuideStepApiResponse, SwitchGuideStepProcessInput
from switch_guides.models.step import SwitchGuideStepComponent, SwitchGuideStepDefinition, SwitchGuideStepDefinitionUiAssets, SwitchGuideStepStatus, SwitchGuideStepStatusProgress
from switch_guides.tasks.GuideStepDefinitionTask import GuideStepDefinitionTask
from switch_guides.utils.utils import ApiInputs
from switch_guides.models.enums import StepResultType

import switch_api as sw


class GuideSampleStepName_Template(GuideStepDefinitionTask):
    @property
    def id(self) -> uuid.UUID:
        return uuid.UUID('{GuideStepDefinitionId_Template}')

    @property
    def author(self):
        return '{Author_Template}'

    @property
    def version(self):
        return '0.1.0'

    @property
    def description(self) -> str:
        return """Sample Guide Step Definition. This description is not visible to the user. 
            Please update it with one that would help future authors understand the intention of this Guide Step."""

    @property
    def mapping_entities(self):
        return ['Readings']

    @property
    def schema(self):
        pass

    def definition(self) -> SwitchGuideStepDefinition:
        return SwitchGuideStepDefinition(
            name='Sample Guide Step',
            description='', # Description of the step visible to the user
            icon='map-marker',
            isEnabled=True,
            isHidden=False,
            status=SwitchGuideStepStatus(
                type='Percentage',
                messages={
                    'default': 'This step is under construction.'
                }
            ),
            # Update this component to one that represents the step use case.
            component=SwitchGuideStepComponent(
                type='Vue',
                id='JourneyStepResult',
                attributes={
                    'resultType': StepResultType.StepProgress,
                    'message': 'This step is under construction.'
                }
            ),
            callToAction=None
        )

    def check_status(self, api_inputs: ApiInputs, journey_input: SwitchGuideStepProcessInput) -> SwitchGuideStepStatus:
        """This method will be called by the Guides Backend under two conditions.

            1. When user completes the requirements of a component associated with this step.
            2. Periodically to check the status of the step over time.

        Please take note of these two items:

            1. Only logic to check the current status of the step should exist here
            2. This efficient and quick as possible as the Guides backend would be calling this method regularly until completion.
        """
        status = SwitchGuideStepStatus(
            progress=SwitchGuideStepStatusProgress(
                completionPercentage=0
            )
        )

        return status

    def check_ui_assets(self, step_status: SwitchGuideStepStatus) -> SwitchGuideStepDefinitionUiAssets:
        """This method can be used to dynamically configure certain elements of the Platform Guides UI.
        Avoid external calls in this method. Use the provided step_status parameter to run you conditional logic.
        """
        return None

    def check_ui_component(self, api_inputs: ApiInputs, step_status: SwitchGuideStepStatus, journey_input: SwitchGuideStepProcessInput) -> SwitchGuideStepComponent:
        """This method can be used to dynamically configure return components to be displayed on the step.
        Just like check_status, ensure this method is quick and efficient as possible.
        """
        return None

    def process(self, api_inputs: ApiInputs, journey_input: SwitchGuideStepProcessInput) -> SwitchGuideStepApiResponse:        
        """This method will be called by the Guides Backend under two conditions.
            1. When user completes the requirements of a component associated with this step.

        Run your logic here to extract, process, and export data how ever you see fit.
        User may be waiting on a response so how long this method should run depends on how long a user is willing to wait.
        """
        
        return SwitchGuideStepApiResponse()

task = GuideSampleStepName_Template()

if __name__ == "__main__":
    api_inputs = sw.initialize(api_project_id='96fa3fc9-1bec-4c38-b8d3-bb985e8ad238', environment='Development')

    """ ================== REGISTER TASK ==================
    """

    # response_status, response_data = task.register(api_inputs=api_inputs)

    # print(response_status)
    # print(response_data)

    """ ================== CONFIGURE GUIDE INPUT ======================
    Valid journey_id is only required when your methods depend on it.
    Guides backend will provide the correct journey_id in production.
    """
    guide_input = SwitchGuideStepProcessInput(journey_id='')


    """ ================== RUN PROCESS LOCALLY ======================
    """

    # result = task.process(api_inputs=api_inputs,
    #                       journey_input=guide_input)
    # print(result)

    """ ================== RUN STATUS CHECK LOCALLY ======================
    """

    # status = task.check_status(api_inputs=api_inputs, journey_input=guide_input)
    # print(status)

    """ ================== RUN STATUS CHECK_UI_ASSETS LOCALLY ======================
    """

    # ui_assets = task.check_ui_assets(journey_input=guide_input, step_status=status)
    # print(ui_assets)


    """ ================== RUN STATUS CHECK_UI_COMPONENT LOCALLY ======================
    """

    # component = task.check_ui_component(api_inputs=api_inputs, journey_input=guide_input, step_status=status)
    # print(component)
